@@ -55,7 +55,7 @@ class FilterAPIRouter:
         self.enabled = enabled
 
     def includeFilterOnMethod(self, method: str, filter: types.FunctionType):
-        if (hasattr(_array, '__len__')):
+        if (hasattr(filter, '__len__')):
             for _filter in filter:
                 self.includeFilterOnMethod(method, _filter)
                 return
@@ -70,9 +70,11 @@ class FilterAPIRouter:
 
         return self
 
-    def enable(self, function, filter_classes: array = []) -> Callable:
-        for filter in filter_classes:
-            self.includeFilterOnMethod(function, filter)
+    def InsertMethodLevelFilter(self, filter_classes: array = []) -> Callable:
+        def FilteredMethod(function):
+            for filter in filter_classes:
+                self.includeFilterOnMethod(function.__name__, filter)
+        return FilteredMethod
 
     def includeGlobalFilter(self, filter: types.FunctionType): 
         assert isinstance(filter, types.FunctionType); "The implemented filter must be of type: Function"
